﻿using DotNetCore.CAP;
using Hotline.Share.Dtos.Order;
using MapsterMapper;
using MediatR;
using Microsoft.AspNetCore.Mvc;
using Sharing.Application;
using Sharing.Notifications;
using Sharing.Orders;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Send;
using Sharing.WebCore;
using System.Threading;

namespace Sharing.Api.Controllers
{
    /// <summary>
    /// 
    /// </summary>
    public class HotlineMessageReceiveController : Controller
    {
        private readonly IDataOrderRepository _dataOrderRepository;
        private readonly IMediator _mediator;
        private readonly ILogger<HotlineMsgReceiver> _logger;
        private readonly IMapper _mapper;
        private readonly IGetCaseResultReceiveRepository _getCaseResultReceiveRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="dataOrderRepository"></param>
        /// <param name="mediator"></param>
        /// <param name="logger"></param>
        /// <param name="mapper"></param>
        /// <param name="getCaseResultReceiveRepository"></param>
        public HotlineMessageReceiveController(IDataOrderRepository dataOrderRepository, IMediator mediator, ILogger<HotlineMsgReceiver> logger, IMapper mapper
            , IGetCaseResultReceiveRepository getCaseResultReceiveRepository)
        {
            _dataOrderRepository = dataOrderRepository;
            _mediator = mediator;
            _logger = logger;
            _mapper = mapper;
            _getCaseResultReceiveRepository = getCaseResultReceiveRepository;
        }

        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderCreated)]
        public async Task ReceiveOrderCreated(OrderDto dto)
        {
            // //todo receive mq msg, write into db, publish inprocess msg
            // _logger.LogInformation("rec order");
            // await _dataOrderRepository.AddAsync(new DataOrder(), HttpContext.RequestAborted);

             await _mediator.Publish(new OrderCreatedNotification(new DataOrder()));
            // _logger.LogInformation("publish order success!");
        }

        /// <summary>
        /// 服务工单交办处理
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderCreated)]
        [CapSubscribe("GetCaseResultReceive")]
        public async Task GetCaseResultReceive(GetCaseResultReceiveInfo dto)
        {
            var data = _mapper.Map<GetCaseResultReceive>(dto);

            //将上报信息写入本地库
             await _getCaseResultReceiveRepository.AddAsync(data);

            //信息上报
            await _mediator.Publish(new GetCaseResultReceiveNotification(data));

        }
    }
}
