﻿using Sharing.Province.Dtos;
using Sharing.Province.Dtos.HuiJu;
using Sharing.Province.Dtos.XieTong.Send;
using XF.Domain.Dependency;

namespace Sharing.Province;

/// <summary>
/// 默认策略（保持原数据策略）
/// </summary>
public class DefaultPusher : IProvincePusher
{
    private readonly HuiJuClient _huiJuClient;
    private readonly XieTongClient _xieTongClient;

    /// <summary>
    /// 
    /// </summary>
    /// <param name="huiJuClient"></param>
    /// <param name="xieTongClient"></param>
    public DefaultPusher(HuiJuClient huiJuClient, XieTongClient xieTongClient)
    {
        _huiJuClient = huiJuClient;
        _xieTongClient = xieTongClient;
    }

    public async Task PushOrderCreatedAsync(SubmitCaseInfoRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<SubmitCaseInfoRequest, ProvinceResponse>(request, cancellationToken);
    }

    /// <summary>
    /// 服务工单交办处理
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<ProvinceResponse> PushGetCaseResultReceiveAsync(GetCaseResultReceiveRequest request, CancellationToken cancellationToken)
    {
        return await _xieTongClient.RequestAsync<GetCaseResultReceiveRequest, ProvinceResponse>(request, cancellationToken);
    }
}