﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications;
using Sharing.Province.Dtos.HuiJu;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Send;
using XF.Domain.Exceptions;

namespace Sharing.Province.Handlers
{
    /// <summary>
    /// 
    /// </summary>
    public class GetCaseResultReceiveHandler : INotificationHandler<GetCaseResultReceiveNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        public GetCaseResultReceiveHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
        }

        /// <summary>
        /// 服务工单交办处理
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(GetCaseResultReceiveNotification notification, CancellationToken cancellationToken=default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<GetCaseResultReceiveInfo>(notification.Data);
            var data = new GetCaseResultReceiveData
            {
                GetCaseResultReceiveInfos = new List<GetCaseResultReceiveInfo>
                {
                    dataReceive
                }
            };

            var request = new GetCaseResultReceiveRequest();
            request.SetData(data);

            await pusher.PushGetCaseResultReceiveAsync(request, cancellationToken);
        }
    }
}
